# bindgen-generated [rust](https://rust-lang.org) bindings for [H3](https://uber.github.io/h3)

These bindings are basically just the autogenerated bindings emitted by [bindgen](https://github.com/rust-lang/rust-bindgen). The bindings
compile using the included (referenced via a git submodule) H3 source code. H3 will be statically linked into the binary, so there is
no need to install a system-wide libh3.

